'''
Robot Framework Workbench

Copyright (c) 2012 Bryan Oakley

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''

__version__ = "0.5"

from rwb.misc import socket_listener
from rwb.misc.debuglibrary import debuglibrary as DebugLibrary

# these will be set by the app after Tkinter is initialized
FONT_SCHEME = None
COLOR_SCHEME = None

